<!--
SPDX-License-Identifier: CC-BY-SA-4.0

Copyright (C) 2026 embedded brains GmbH & Co. KG
-->
## Overview

The *specmake* Python package provides utilities to build packages of software
products along with their documentation.  The package uses the specification
item framework provided by
[specitems](https://github.com/specthings/specitems)
for the package build definition.  The software specification framework is
provided by
[specware](https://github.com/specthings/specware).

The package is maintained by the
[specthings](https://github.com/specthings)
project.

## Contributing

Please refer to our
[Contributing Guidelines](https://github.com/specthings/specmake/blob/main/CONTRIBUTING.md).
